'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var axios = _interopDefault(require('axios'));

var handleRejected = function handleRejected(error) {
  if (axios.isCancel(error)) {
    return Promise.resolve();
  }

  return Promise.reject(error);
};

function useAxiosEffect(effect, deps) {
  React.useEffect(function () {
    var cancelTokenSource = axios.CancelToken.source();
    effect(cancelTokenSource.token).catch(function (error) {
      cancelTokenSource = undefined;
      return Promise.reject(error);
    }).then(function (response) {
      cancelTokenSource = undefined;
      return response;
    }).catch(handleRejected);
    return function () {
      if (!cancelTokenSource) {
        return;
      }

      cancelTokenSource.cancel();
      cancelTokenSource = undefined;
    };
  }, deps);
}

exports.useAxiosEffect = useAxiosEffect;
