import { useEffect } from 'react';
import axios from 'axios';

var handleRejected = function handleRejected(error) {
  if (axios.isCancel(error)) {
    return Promise.resolve();
  }

  return Promise.reject(error);
};

function useAxiosEffect(effect, deps) {
  useEffect(function () {
    var cancelTokenSource = axios.CancelToken.source();
    effect(cancelTokenSource.token).catch(function (error) {
      cancelTokenSource = undefined;
      return Promise.reject(error);
    }).then(function (response) {
      cancelTokenSource = undefined;
      return response;
    }).catch(handleRejected);
    return function () {
      if (!cancelTokenSource) {
        return;
      }

      cancelTokenSource.cancel();
      cancelTokenSource = undefined;
    };
  }, deps);
}

export { useAxiosEffect };
